@@ -59,6 +59,7 @@ def convert(
     overwrite_input_shape: Optional[List[str]] = None,
     keep_ncw_or_nchw_or_ncdhw_input_names: Optional[List[str]] = None,
     keep_nwc_or_nhwc_or_ndhwc_input_names: Optional[List[str]] = None,
+    output_names_to_interrupt_model_conversion: Optional[List[str]] = None,
     replace_argmax_to_reducemax_and_indicies_is_int64: Optional[bool] = False,
     replace_argmax_to_reducemax_and_indicies_is_float32: Optional[bool] = False,
     replace_argmax_to_fused_argmax_and_indicies_is_int64: Optional[bool] = False,
@@ -66,6 +67,7 @@ def convert(
     fused_argmax_scale_ratio: Optional[float] = 0.5,
     replace_asin_to_pseudo_asin: Optional[bool] = False,
     replace_acos_to_pseudo_acos: Optional[bool] = False,
+    replace_abs_to_pseudo_abs: Optional[bool] = False,
     replace_prelu_to_pseudo_prelu: Optional[bool] = False,
     replace_leakyrelu_to_pseudo_leakyrelu: Optional[bool] = False,
     replace_power_to_pseudo_power: Optional[bool] = False,
@@ -204,6 +206,13 @@ def convert(
         e.g. \n
         --keep_nwc_or_nhwc_or_ndhwc_input_names=['input0', 'input1', 'input2']
 
+    output_names_to_interrupt_model_conversion: Optional[List[str]]
+        Output names that interrupt model conversion.\n
+        Interrupts model transformation at the specified output name\n
+        and outputs the model partitioned into subgraphs.\n\n
+        e.g.\n
+        --output_names_to_interrupt_model_conversion "output0" "output1" "output2"
+
     replace_argmax_to_reducemax_and_indicies_is_int64: Optional[bool]
         Replace ArgMax with a ReduceMax. The returned indicies are int64.\n
         Only one of replace_argmax_to_reducemax_and_indicies_is_int64 and \n
@@ -254,6 +263,9 @@ def convert(
     replace_acos_to_pseudo_acos: Optional[bool]
         Replace Acos with a pseudo Acos.
 
+    replace_abs_to_pseudo_abs: Optional[bool]
+        Replace Abs with a pseudo Abs.
+
     replace_prelu_to_pseudo_prelu: Optional[bool]
         Replace PReLU with a pseudo PReLU.
 
@@ -460,6 +472,7 @@ def convert(
         'fused_argmax_scale_ratio': fused_argmax_scale_ratio,
         'replace_asin_to_pseudo_asin': replace_asin_to_pseudo_asin,
         'replace_acos_to_pseudo_acos': replace_acos_to_pseudo_acos,
+        'replace_abs_to_pseudo_abs': replace_abs_to_pseudo_abs,
         'replace_prelu_to_pseudo_prelu': replace_prelu_to_pseudo_prelu,
         'replace_leakyrelu_to_pseudo_leakyrelu': replace_leakyrelu_to_pseudo_leakyrelu,
         'replace_power_to_pseudo_power': replace_power_to_pseudo_power,
@@ -541,9 +554,14 @@ def convert(
         ]
 
         # List Output
-        output_names = [
-            graph_output.name for graph_output in graph.outputs
-        ]
+        if not output_names_to_interrupt_model_conversion:
+            output_names = [
+                graph_output.name for graph_output in graph.outputs
+            ]
+        else:
+            output_names = [
+                output_op_name for output_op_name in output_names_to_interrupt_model_conversion
+            ]
         outputs = [
             layer_info['tf_node'] \
                 for opname, layer_info in tf_layers_dict.items() \
@@ -969,6 +987,18 @@ def main():
             'e.g. \n' +
             '--keep_nwc_or_nhwc_or_ndhwc_input_names "input0" "input1" "input2"'
     )
+    parser.add_argument(
+        '-onimc',
+        '--output_names_to_interrupt_model_conversion',
+        type=str,
+        nargs='+',
+        help=\
+            'Output names that interrupt model conversion. \n' +
+            'Interrupts model transformation at the specified output name \n' +
+            'and outputs the model partitioned into subgraphs. \n\n' +
+            'e.g. \n' +
+            '--output_names_to_interrupt_model_conversion "output0" "output1" "output2"'
+    )
     rar_group = parser.add_mutually_exclusive_group()
     rar_group.add_argument(
         '-rari64',
@@ -1043,6 +1073,12 @@ def main():
         action='store_true',
         help='Replace Acos with a pseudo Acos.'
     )
+    parser.add_argument(
+        '-rabs',
+        '--replace_abs_to_pseudo_abs',
+        action='store_true',
+        help='Replace Abs with a pseudo Abs.'
+    )
     parser.add_argument(
         '-rpr',
         '--replace_prelu_to_pseudo_prelu',
@@ -1145,6 +1181,7 @@ def main():
         overwrite_input_shape=args.overwrite_input_shape,
         keep_ncw_or_nchw_or_ncdhw_input_names=args.keep_ncw_or_nchw_or_ncdhw_input_names,
         keep_nwc_or_nhwc_or_ndhwc_input_names=args.keep_nwc_or_nhwc_or_ndhwc_input_names,
+        output_names_to_interrupt_model_conversion=args.output_names_to_interrupt_model_conversion,
         replace_argmax_to_reducemax_and_indicies_is_int64=args.replace_argmax_to_reducemax_and_indicies_is_int64,
         replace_argmax_to_reducemax_and_indicies_is_float32=args.replace_argmax_to_reducemax_and_indicies_is_float32,
         replace_argmax_to_fused_argmax_and_indicies_is_int64=args.replace_argmax_to_fused_argmax_and_indicies_is_int64,
@@ -1152,6 +1189,7 @@ def main():
         fused_argmax_scale_ratio=args.fused_argmax_scale_ratio,
         replace_asin_to_pseudo_asin=args.replace_asin_to_pseudo_asin,
         replace_acos_to_pseudo_acos=args.replace_acos_to_pseudo_acos,
+        replace_abs_to_pseudo_abs=args.replace_abs_to_pseudo_abs,
         replace_prelu_to_pseudo_prelu=args.replace_prelu_to_pseudo_prelu,
         replace_leakyrelu_to_pseudo_leakyrelu=args.replace_leakyrelu_to_pseudo_leakyrelu,
         replace_power_to_pseudo_power=args.replace_power_to_pseudo_power,
